.. image:: https://user-images.githubusercontent.com/5915802/29747597-21bd1200-8b1d-11e7-9796-3a6c6a26f032.png

|Travis Build Status| |Codacy Project Status| |Documentation Status| |MIT licensed|

Python language runner for `Gauge`_.

+------------------+------------------+------------------+-----------------+
|   `User Docs`_   |  `Setup Guide`_  |   `Examples`_    | `Contributing`_ |
+==================+==================+==================+=================+
|      |i1|\       |      |i2|\       |      |i3|\       |      |i4|\      |
|                  |                  |                  |                 |
| Learn more about | Development setup| Some Gauge Python| Contribution    |
| Gauge Python.    | guide for Gauge  | example projects.| guide for Gauge |
|                  | Python.          |                  | Python?         |
+------------------+------------------+------------------+-----------------+

Issues
------

If you find any issues or have any feature requests, please file them in the `issue tracker`_.

.. _issue tracker: https://github.com/getgauge/gauge-python/issues

License
-------

The Gauge-Python is an open-sourced software licensed under the `MIT license`_.

.. _User Docs: https://gauge-python.readthedocs.io
.. _Setup Guide: https://gauge-python.readthedocs.io/en/latest/contributing.html#development-guide
.. _Examples: https://gauge-python.readthedocs.io/en/latest/getting-started.html#examples
.. _Contributing: https://gauge-python.readthedocs.io/en/latest/contributing.html
.. _Gauge: https://github.com/getgauge/gauge
.. _MIT license: http://opensource.org/licenses/MIT

.. |i1| image:: https://d3i6fms1cm1j0i.cloudfront.net/github/images/techdocs.png
   :target: https://gauge-python.readthedocs.io
.. |i2| image:: https://d3i6fms1cm1j0i.cloudfront.net/github/images/setup.png
   :target: https://gauge-python.readthedocs.io/en/latest/contributing.html#development-guide
.. |i3| image:: https://d3i6fms1cm1j0i.cloudfront.net/github/images/roadmap.png
   :target: https://gauge-python.readthedocs.io/en/latest/getting-started.html#examples
.. |i4| image:: https://d3i6fms1cm1j0i.cloudfront.net/github/images/contributing.png
   :target: https://gauge-python.readthedocs.io/en/latest/contributing.html
.. |Documentation Status| image:: https://readthedocs.org/projects/gauge-python/badge/?version=latest
   :target: http://gauge-python.readthedocs.org/en/latest/?badge=latest
.. |Travis Build Status| image:: https://travis-ci.org/getgauge/gauge-python.svg?branch=master
   :target: https://travis-ci.org/getgauge/gauge-python
.. |Codacy Project Status| image:: https://api.codacy.com/project/badge/Grade/2b96566538d1445685f9ad7792456b97
   :target: https://www.codacy.com/app/kashishmunjal/gauge-python?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=getgauge/gauge-python&amp;utm_campaign=Badge_Grade
.. |MIT licensed| image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: https://github.com/getgauge/gauge-python/blob/master/LICENSE.txt
